@@ -191,9 +191,9 @@ sub color_mapping {
             'gradient' => {
                 'direction' => 'horizontal',
                 'colors'    => {
-                    'red'   => [255, 0,   0],
-                    'green' => [0,   255, 0],
-                    'blue'  => [0,   0,   255]
+                    'red'   => [255, 255, 0,   0,   0,   255],
+                    'green' => [0,   255, 255, 255, 0,   0],
+                    'blue'  => [0,   0,   0,   255, 255, 255]
                 }
             }
         }
@@ -210,9 +210,9 @@ sub color_mapping {
             'gradient' => {
                 'direction' => 'vertical',
                 'colors'    => {
-                    'red'   => [255, 0,   0],
-                    'green' => [0,   255, 0],
-                    'blue'  => [0,   0,   255]
+                    'red'   => [255, 255, 0,   0,   0,   255],
+                    'green' => [0,   255, 255, 255, 0,   0],
+                    'blue'  => [0,   0,   0,   255, 255, 255]
                 }
             }
         }
@@ -792,7 +792,7 @@ sub polygons {
 sub filled_polygons {
     
     print_it($F, 'Filled Polygon Test');
-
+    $F->mask_mode() if ($F->{'ACCELERATED'});
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
@@ -813,6 +813,7 @@ sub filled_polygons {
 sub hatch_filled_polygons {
     
     print_it($F, 'Hatch Filled Polygon Test');
+    $F->mask_mode() if ($F->{'ACCELERATED'});
 
     my $s = time + $factor;
     while (time < $s) {
@@ -837,6 +838,7 @@ sub hatch_filled_polygons {
 sub gradient_polygons {
     my $direction = shift;
     print_it($F, ucfirst($direction) . ' Gradient Polygon Test');
+    $F->mask_mode() if ($F->{'ACCELERATED'});
 
     my $s = time + $factor;
     while (time < $s) {
@@ -869,6 +871,7 @@ sub gradient_polygons {
 sub texture_filled_polygons {
     
     print_it($F, 'Texture Filled Polygon Test');
+    $F->mask_mode() if ($F->{'ACCELERATED'});
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
     while (time < $s) {
@@ -1275,7 +1278,7 @@ sub animated {
                     my $fps   = 0;
                     my $start = time;
                     my $s     = time + ($factor * 2);
-                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
+#                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                             if (time > $s * 2) {
@@ -1301,7 +1304,7 @@ sub animated {
                     } ## end while (time <= $s)
                 } ## end if (defined($image))
             } ## end foreach my $bench (0 .. 1)
-#            last if ($XX <= 320 || $rpi);
+            last if ($XX <= 320);
         } ## end for my $count (0 .. 1)
     } ## end foreach my $info (@list)
 } ## end sub animated
